import type { SimplifiedSchema } from 'mongodb-schema';
import { type PreferencesAccess } from 'compass-preferences-model/provider';
import type { AtlasAuthService, AtlasService } from '@mongodb-js/atlas-service/provider';
import type { Document } from 'mongodb';
import type { LoggerAndTelemetry } from '@mongodb-js/compass-logging';
type GenerativeAiInput = {
    userInput: string;
    collectionName: string;
    databaseName: string;
    schema?: SimplifiedSchema;
    sampleDocuments?: Document[];
    signal?: AbortSignal;
};
type AIAggregation = {
    content: {
        aggregation?: {
            pipeline?: string;
        };
    };
};
type AIQuery = {
    content: {
        query: Record<'filter' | 'project' | 'collation' | 'sort' | 'skip' | 'limit', string>;
        aggregation?: {
            pipeline: string;
        };
    };
};
export declare class AtlasAiService {
    private atlasService;
    private atlasAuthService;
    private preferences;
    private logger;
    private initPromise;
    constructor(atlasService: AtlasService, atlasAuthService: AtlasAuthService, preferences: PreferencesAccess, logger: LoggerAndTelemetry);
    private throwIfAINotEnabled;
    enableFeature(): Promise<void>;
    disableFeature(): Promise<void>;
    private getAIFeatureEnablement;
    setupAIAccess(): Promise<void>;
    private getQueryOrAggregationFromUserInput;
    getAggregationFromUserInput(input: GenerativeAiInput): Promise<AIAggregation>;
    getQueryFromUserInput(input: GenerativeAiInput): Promise<AIQuery>;
    private validateAIQueryResponse;
    private validateAIAggregationResponse;
    private validateAIFeatureEnablementResponse;
    private hasExtraneousKeys;
}
export {};
//# sourceMappingURL=atlas-ai-service.d.ts.map